@@ -1,4 +1,4 @@
-/* $Id: xfsm-manager.c 28938 2008-11-28 06:14:37Z kelnos $ */
+/* $Id$ */
 /*-
  * Copyright (c) 2003-2006 Benedikt Meurer <benny@xfce.org>
  * Copyright (c) 2008 Brian Tarricone <bjt23@cornell.edu>
@@ -1625,7 +1625,8 @@ xfsm_manager_store_session (XfsmManager *manager)
     {
       backup = g_strconcat (manager->session_file, ".bak", NULL);
       unlink (backup);
-      link (manager->session_file, backup);
+      if (link (manager->session_file, backup))
+          g_warning ("Failed to create session file backup");
       g_free (backup);
     }
 
